<?php

namespace Drupal\graphql_vertex_ai\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * GraphQL Vertex AI settings.
 */
class GraphqlVertexAiSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'graphql_vertex_ai_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $settings = $this->config('graphql_vertex_ai.settings');

    $form['key'] = [
      '#title' => 'Key',
      '#type' => 'key_select',
      '#description' => $this->t('Service account authentication_multivalue key.'),
      '#default_value' => $settings->get('key'),
      '#key_filters' => [
        'type' => 'authentication_multivalue',
      ],
      '#config' => [
        'key' => 'graphql_vertex_ai.settings:key',
      ],
    ];

    $form['project_id'] = [
      '#title' => $this->t('Project ID'),
      '#type' => 'textfield',
      '#description' => $this->t('Google project ID.'),
      '#default_value' => $settings->get('project_id'),
      '#config' => [
        'project_id' => 'graphql_vertex_ai.settings:project_id',
      ],
    ];

    $form['location'] = [
      '#title' => $this->t('Location'),
      '#type' => 'textfield',
      '#description' => $this->t('Google project location.'),
      '#default_value' => $settings->get('location'),
      '#config' => [
        'location' => 'graphql_vertex_ai.settings:location',
      ],
    ];

    $form['data_store_id'] = [
      '#title' => $this->t('Data Store ID'),
      '#type' => 'textfield',
      '#description' => $this->t('Google dataStore ID.'),
      '#default_value' => $settings->get('data_store_id'),
      '#config' => [
        'data_store_id' => 'graphql_vertex_ai.settings:data_store_id',
      ],
    ];

    $form['serving_config_id'] = [
      '#title' => $this->t('Serving Config ID'),
      '#type' => 'textfield',
      '#description' => $this->t('Google servingConfig ID. Usually the ID of your Agent in Agent Builder.'),
      '#default_value' => $settings->get('serving_config_id'),
      '#config' => [
        'serving_config_id' => 'graphql_vertex_ai.settings:serving_config_id',
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    parent::submitForm($form, $form_state);

    $this->config('graphql_vertex_ai.settings')
      ->set('key', $form_state->getValue('key'))
      ->set('project_id', $form_state->getValue('project_id'))
      ->set('location', $form_state->getValue('location'))
      ->set('data_store_id', $form_state->getValue('data_store_id'))
      ->set('serving_config_id', $form_state->getValue('serving_config_id'))
      ->save();
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['graphql_vertex_ai.settings'];
  }

}
