<?php

namespace Drupal\graphql_vertex_ai\Plugin\GraphQL\DataProducer;

use Drupal\Component\Serialization\Json;
use Drupal\graphql\Plugin\GraphQL\DataProducer\DataProducerPluginBase;
use Google\Cloud\DiscoveryEngine\V1\CompleteQueryResponse;

/**
 * The data producer for autocomplete response suggestions.
 *
 * @DataProducer(
 *   id = "vertex_ai_autocomplete_response_suggestions",
 *   name = @Translation("Autocomplete response suggestions"),
 *   description = @Translation("The suggestions from an autocomplete response or null if empty."),
 *   produces = @ContextDefinition("any",
 *     label = @Translation("Suggestions")
 *   ),
 *   consumes = {
 *     "response" = @ContextDefinition("any",
 *       label = @Translation("Autocomplete Reponse"),
 *       required = TRUE
 *     ),
 *   }
 * )
 */
class VertexAiAutocompleteResponseSuggestions extends DataProducerPluginBase {

  /**
   * Resolver.
   *
   * @param \Google\Cloud\DiscoveryEngine\V1\CompleteQueryResponse $response
   *   The search query.
   *
   * @return array|null
   *   The result.
   */
  public function resolve(CompleteQueryResponse $response): ?array {
    $data = Json::decode($response->serializeToJsonString());
    if (is_array($data['querySuggestions'])) {
      return array_map(fn($record) => $record['suggestion'], $data['querySuggestions']);
    }
    return NULL;
  }

}
