<?php

namespace Drupal\graphql_vertex_ai\Plugin\GraphQL\DataProducer;

use Drupal\Component\Serialization\Json;
use Drupal\Component\Utility\NestedArray;
use Drupal\graphql\Plugin\GraphQL\DataProducer\DataProducerPluginBase;
use Google\Cloud\DiscoveryEngine\V1\SearchResponse\SearchResult;

/**
 * The data producer for search result data.
 *
 * @DataProducer(
 *   id = "vertex_ai_search_result_derived_data",
 *   name = @Translation("Search result data"),
 *   description = @Translation("Search result data"),
 *   produces = @ContextDefinition("string",
 *     label = @Translation("Summary text")
 *   ),
 *   consumes = {
 *     "result" = @ContextDefinition("any",
 *       label = @Translation("Search Result"),
 *       required = TRUE
 *     ),
 *     "field" = @ContextDefinition("string",
 *       label = @Translation("Field data path"),
 *       required = TRUE
 *     ),
 *   }
 * )
 */
class VertexAiSearchResultDerivedData extends DataProducerPluginBase {

  /**
   * Resolver.
   *
   * @param \Google\Cloud\DiscoveryEngine\V1\SearchResponse\SearchResult $result
   *   An individual search result.
   * @param string $field
   *   The field data you want in a hierarchy eg. snippets.0.snippet.
   *
   * @return string|null
   *   The result.
   */
  public function resolve(SearchResult $result, string $field): ?string {
    $parents = explode('.', $field);
    // @todo There may be a more performant way to do this.
    $data = Json::decode($result->getDocument()->getDerivedStructData()->serializeToJsonString());
    $value = NestedArray::getValue($data, $parents);
    return (!empty($value)) ? $value : NULL;
  }

}
